==> artemis-server-1.0.0-sources.jar: org/apache/activemq/artemis/core/protocol/core/impl/wireformat/ClusterConnectMessage.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.core.protocol.core.impl.wireformat;

import org.apache.activemq.artemis.api.core.ActiveMQBuffer;
import org.apache.activemq.artemis.core.protocol.core.impl.PacketImpl;

public class ClusterConnectMessage extends PacketImpl
{
   private String clusterUser;
   private String clusterPassword;

   public ClusterConnectMessage()
   {
      super(CLUSTER_CONNECT);
   }

   public ClusterConnectMessage(String clusterUser, String clusterPassword)
   {
      super(CLUSTER_CONNECT);
      this.clusterUser = clusterUser;
      this.clusterPassword = clusterPassword;
   }

   @Override
   public void encodeRest(final ActiveMQBuffer buffer)
   {
      buffer.writeString(clusterUser);
      buffer.writeString(clusterPassword);
   }

   @Override
   public void decodeRest(final ActiveMQBuffer buffer)
   {
      clusterUser = buffer.readString();
      clusterPassword = buffer.readString();
   }



   public String getClusterUser()
   {
      return clusterUser;
   }

   public String getClusterPassword()
   {
      return clusterPassword;
   }
}

==> artemis-server-2.19.1-sources.jar: org/apache/activemq/artemis/core/protocol/core/impl/wireformat/ClusterConnectMessage.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.activemq.artemis.core.protocol.core.impl.wireformat;

import org.apache.activemq.artemis.api.core.ActiveMQBuffer;
import org.apache.activemq.artemis.core.protocol.core.impl.PacketImpl;

public class ClusterConnectMessage extends PacketImpl {

   private String clusterUser;
   private String clusterPassword;

   public ClusterConnectMessage() {
      super(CLUSTER_CONNECT);
   }

   public ClusterConnectMessage(String clusterUser, String clusterPassword) {
      super(CLUSTER_CONNECT);
      this.clusterUser = clusterUser;
      this.clusterPassword = clusterPassword;
   }

   @Override
   public void encodeRest(final ActiveMQBuffer buffer) {
      buffer.writeString(clusterUser);
      buffer.writeString(clusterPassword);
   }

   @Override
   public void decodeRest(final ActiveMQBuffer buffer) {
      clusterUser = buffer.readString();
      clusterPassword = buffer.readString();
   }

   public String getClusterUser() {
      return clusterUser;
   }

   public String getClusterPassword() {
      return clusterPassword;
   }
}
